<?php

namespace Drupal\commerce_gmo_linktypeplus\Plugin\Commerce\CheckoutPane;

use Drupal\Core\Form\FormStateInterface;
use Drupal\commerce_payment\Plugin\Commerce\CheckoutPane\PaymentInformation;

/**
 * Provides the payment information pane.
 *
 * Disabling this pane will automatically
 * disable the payment process pane,
 * since they are always used together.
 * Developers subclassing this pane
 * should use hook_commerce_checkout_pane_info_alter(array &$panes)
 * to
 * point $panes['payment_information']['class']
 * to the new child class.
 *
 * @CommerceCheckoutPane(
 *   id = "gmo_payment_information",
 *   label = @Translation("GMO LinkTypePlus Payment information"),
 *   default_step = "order_information",
 *   wrapper_element = "fieldset",
 * )
 */
class GmoPaymentInformation extends PaymentInformation {

  /**
   * {@inheritdoc}
   */
  public function buildPaneForm(array $pane_form, FormStateInterface $form_state, array &$complete_form) {
    $pane_form = parent::buildPaneForm($pane_form, $form_state, $complete_form);

    /** @var \Drupal\commerce_payment\PaymentGatewayStorageInterface $payment_gateway_storage */
    $payment_gateway_storage = $this->entityTypeManager->getStorage('commerce_payment_gateway');
    // Load the payment gateways. This fires an event for filtering the
    // available gateways, and then evaluates conditions on all remaining ones.
    $payment_gateways = $payment_gateway_storage->loadMultipleForOrder($this->order);
    // Can't proceed without any payment gateways.
    if (empty($payment_gateways)) {
      $this->messenger()->addError($this->noPaymentGatewayErrorMessage());
      return $pane_form;
    }

    foreach ($payment_gateways as $payment_gateway) {
      $plugin = $payment_gateway->getPlugin();
      if ($payment_gateway->getPluginId() == 'link_type_plus') {
        $option_content['cnt'] = [
          '#theme' => 'custom_commerce_payment_method',
          '#payment_details' => [
            'label' => $plugin->getDisplayLabel(),
            'description' => $plugin->getConfiguration()['description'],
            'icon' => $plugin->getConfiguration()['icon'],
            'payment_methods' => implode(" ", $plugin->getConfiguration()['payment_methods']),
          ],
        ];
        $machine_name = $payment_gateway->getPluginId();
        $pane_form['payment_method']['#options'][$machine_name] = $option_content['cnt'];
      }

    }

    return $pane_form;
  }

}
